{% load i18n %}
{% load static %}
{% load humanize %}

<div class="modal-content">
    <div class="modal-header">
        <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">
            &times;
        </span></button>
        <h4 class="modal-title" id="modalTitle">{% translate 'Create Request' %}</h4>
    </div>

    <div class="modal-body">

        <form action="{% url 'blueprints:create_request' %}" method="POST" class="form-horizontal">
            {% csrf_token %}
            <input type=hidden name="blueprint_id" value="{{ blueprint.blueprint_id }}" />
            <div class="form-group">
                <label class="col-sm-4">{% translate "Blueprint Type" %}</label>
                <div class='col-sm-8'>{{ blueprint.type_icon }} {{ blueprint.type_name }}</div>
            </div>
            <div class="form-group">
                <label class="col-sm-4">{% translate "Blueprint Location" %}</label>
                <div class='col-sm-8'>{{ blueprint.location }}</div>
            </div>
            <div class="form-group">
                <label class="col-sm-4">{% translate "Material Efficiency" %}</label>
                <div class='col-sm-8'>{{ blueprint.material_efficiency }}</div>
            </div>
            <div class="form-group">
                <label class="col-sm-4">{% translate "Time Efficiency" %}</label>
                <div class='col-sm-8'>{{ blueprint.time_efficiency }}</div>
            </div>
            <div class="form-group">
                <label for="runs" class="col-sm-4">Runs</label>
                <div class="col-sm-8">
                <input type="number" class="form-control" id="runs" name="runs" />
                <p class="help-block">Leave blank for maximum runs.</p>
                </div>
            </div>
            <div class="form-group">
            <div class="col-sm-12">
                <div class="pull-right">
                <button type="submit" class="btn btn-success">
                    {% translate 'Create Request' %}
                </button></div>
            </div>
            </div>
        </form>
    </div>

    <div class="modal-footer">
        </div>
</div>
